//----------------------------------------------------------------------------------
//	FILE:			PWM_Demo.C
//
//	Description:	PWM s/w driver evaluation
//
//	Version: 		2.00
//
//  Target:  		TMS320F280x (F2808, F2806, F2801).  
//
//	Type: 			Device dependent
//
//----------------------------------------------------------------------------------
//  Copyright Texas Instruments  2004-2005                                				
//----------------------------------------------------------------------------------
//  Revision History:
//----------------------------------------------------------------------------------
//  Date	  | Description
//----------------------------------------------------------------------------------
//  06/30/05  | Release 1.0  		New release.
//----------------------------------------------------------------------------------
//  11/15/05  | Release 1.1  		Documentation and source cleanup.
//---------------------------------------------------------------------------------- 
//---------------------------------------------------------------------------------- 
//  06/27/06  | Release 2.0  	   Updated all the projects to the rev 2.0  format
//            |                     with the addition of memory blocking and new
//            |                     directory structure and simplified libraries.
//---------------------------------------------------------------------------------- 
#include "DSP280x_Compact.h"     	// DSP280x Headerfile
#include "Dplib280x.h"

//==================================================================================
// Incremental build options for module check-out
//----------------------------------------------------------------------------------
// Note: make sure same conditional assembly option is chosen in
// file PWM-Eval-ISR.asm
//----------------------------------------------------------------------------------
// HiRes examples
#define	IB11	0	// HR-Buck - Single module (without Deadband)
#define	IB14	0	// HR-Phase Shifted Full Bridge w/ DB control
#define	IB15A	1	// HiRes PWM module with Sine modulation
#define	IB15B	0	// HiRes PWM module with Ramp modulation

//----------------------------------------------------------------------------------

//==================================================================================
// Interrupt Framework options
//----------------------------------------------------------------------------------
// Note: make sure same conditional assembly option is chosen in
// file PWM-Eval-ISR.asm
//----------------------------------------------------------------------------------
#define	EPWMn_ISR	1	// ISR triggered by EPWM
#define	ADC_ISR		0	// ISR triggered by ADC EOS

// If EPWM_ISR = 1, then choose which module
#define	EPWM1_triggers_ISR	0	// ISR triggered by EPWM1
#define	EPWM2_triggers_ISR	0	// ISR triggered by EPWM2
#define	EPWM3_triggers_ISR	0	// ISR triggered by EPWM3
#define	EPWM4_triggers_ISR	0	// ISR triggered by EPWM4
#define	EPWM5_triggers_ISR	0	// ISR triggered by EPWM5
#define	EPWM6_triggers_ISR	1	// ISR triggered by EPWM6
//----------------------------------------------------------------------------------


// General System Prototype statements
//----------------------------------------------------------------------------------
// This is standard system init stuff, no need to change
void InitSysCtrl(void);
void InitPieCtrl(void);
void InitPieVectTable(void);        

// Declare function prototypes here
//----------------------------------------------------------------------------------
void ISR_Init(void);
void ISR_Run(void);


//==================================================================================
// Variable Declarations
//----------------------------------------------------------------------------------
// General "System nets" - Useful for debug

	int16 WriteFlag =1;
	int32 WriteValue  = 0x00024200;
	int16 phase, dbLeft, dbRight;
	int16 duty1, duty2, duty3;
	int16 Gain, Offset, Freq, SineOut, RampOut, Duty;
	

// Scale Factors for ePWM1-4, [0] is dummy
	int16 MEP_ScaleFactor[5];

//----------------------------------------------------------------------------------
	Uint32 BackTicker=0; // Variable to provide user feedback about real time debug

//==================================================================================
void main(void)
{

//----------------------------------------------------------------------------------
// Generic Chip level Init.
//----------------------------------------------------------------------------------
	InitSysCtrl();
	DINT;
	InitPieCtrl();
   
// 	Disable CPU interrupts and clear all CPU interrupt flags:
	IER = 0x0000;
	IFR = 0x0000;
	InitPieVectTable();

// Configure the GPIO for EPWM functions
// (later this section will be made into a GPIO function init.
	EALLOW;
	GpioCtrlRegs.GPAMUX1.all=0x55555555; // GPIO0-15 for PWM 

	// master clock sync/enable for all ePWMs
	SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 1;
	EDIS;
	
	// wait for a valid SFO value from ePWM2
	MEP_ScaleFactor[1] = 0;
	while ( MEP_ScaleFactor[1] == 0 ) SFO_MepDis(1);
	MEP_ScaleFactor[0] = MEP_ScaleFactor[1]; // prime 0th MEP SF
	MEP_ScaleFactor[2] = MEP_ScaleFactor[1]; // prime 2nd MEP SF
	MEP_ScaleFactor[3] = MEP_ScaleFactor[1]; // prime 3rd MEP SF
	MEP_ScaleFactor[4] = MEP_ScaleFactor[1]; // prime 4th MEP SF

//===========================================================================

//===========================================================================
// Other One-Time Initialize Fuctions
//===========================================================================
// None so far.


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Incremental build options via Module connections to system Nets.
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

// Some useful Period vs Frequency values for Sysclk = 100 MHz
//	Period	Frequency
//	1000	100 KHz
//	800		125 KHz
//	600		167 KHz
//	500		200 KHz
//	400		250 KHz
//	300		333 KHz
//	250		400 KHz
//	200		500 KHz
//	100		1 MHz
//	50		2 MHz
//	25		4 MHz
//	12		8.33 MHz
//	10		10.0 MHz

//=============================================================
#if (IB11) // HiRes Buck PWM driver checkout
//=============================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		HrBuckDrvCnf(1, 500);		// ePWM1 target, 200KHz PWM
		ISR_Init();					// ASM ISR init
		duty1 = 0x6000;
		HRBUCK_In1 = &duty1;

#endif // (IB11)


//=============================================================
#if (IB14) // HiRes PSFB driver checkout
//=============================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		HrPSFBDrvCnf(1, 1000);		// Init ePWM module 1,2 & 3
		ISR_Init();					// ASM ISR init

		phase = 0;
		dbLeft = 0;
		dbRight = 0;

		PSFB_phase   = &phase;
		PSFB_dbLeft  = &dbLeft;
		PSFB_dbRight = &dbRight;

#endif // (IB14)



//=============================================================
#if (IB15A) // HiRes PWM-DAC driver checkout with Sine modulation
//=============================================================
		TimeBasePeriodCnf(6, 200);	// ISR Timebase only, 500KHz
		HrBuckDrvCnf(1, 12);		// ePWM1 target, 8.33 MHz PWM

// Std resolution buck driver for a comparison
		BuckDrvCnf(2, 12);			// ePWM2 target, 8.33 MHz PWM
		ISR_Init();					// ASM ISR init

		Gain    = 0x2000;
		Offset  = 0x4000;
		Freq    = 0x0010;

	// SINGEN_1CH(1) connections
		SINGEN_1CH_Gain1   = &Gain;
		SINGEN_1CH_Offset1 = &Offset;
		SINGEN_1CH_Freq1   = &Freq;
		SINGEN_1CH_Out1    = &SineOut;

	// HRPWM_DAC_DRV connections
		HRBUCK_In1= &SineOut;
		BUCK_InA2 = &SineOut;
		BUCK_InB2 = &SineOut;

#endif // (IB15A)

//========================================================================
#if (IB15B) // HiRes PWM-DAC driver checkout with Ramp modulation
//========================================================================
		TimeBasePeriodCnf(3, 100);	// Timebase (1000KHz) for SFO_MepEn(3)
		TimeBasePeriodCnf(6, 100);	// ISR Timebase only, 1000KHz
		HrBuckDrvCnf(1, 12);		// ePWM1 target, 8.33MHz PWM
		BuckDrvCnf(2, 12);			// ePWM2 target,  8.33MHz PWM
		ISR_Init();					// ASM ISR init

		Gain    = 0x2000;
		Offset  = 0x4000;
		Freq    = 0x0010;

	// RAMPGEN_1CH(1) connections
		RAMPGEN_1CH_Gain1 = &Gain;
		RAMPGEN_1CH_Offset1 = &Offset;
		RAMPGEN_1CH_Freq1 = &Freq;
		RAMPGEN_1CH_Out1 = &RampOut;

	// HRPWM_DAC_DRV connections
		HRBUCK_In1 = &RampOut;
		BUCK_InA2  = &RampOut;
		BUCK_InB2  = &RampOut;

#endif // (IB15B)


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Interrupt Init section - System Level and Peripheral Level
// (best to run this section last, once all other initialization is done)
//
// Note: Make sure same selection is made in PWM-Eval-ISR.ASM
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#if (EPWMn_ISR) // Here ISR is triggered by EPWMn
//===========================================================================
	IER |= M_INT3; // Enable CPU INT3 connected to EPWM1-6 INTs:


#if (EPWM1_triggers_ISR) // Here ISR is triggered by EPWM1
//---------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM1_INT = &ISR_Run;	// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx1 = 1;	// PIE level enable, Grp3 / Int1
// EPWM1 level enable
	EPwm1Regs.ETSEL.bit.INTSEL = 1;		// Select INT on Zero event
	EPwm1Regs.ETSEL.bit.INTEN = 1; 		// Enable INT
	//EPwm1Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm1Regs.ETPS.bit.INTPRD = ET_2ND;	// Generate INT every 2nd event
	//EPwm1Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM1_triggers_ISR)
//---------------------------------------------------------------------

#if (EPWM2_triggers_ISR) // Here ISR is triggered by EPWM2
//---------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM2_INT = &ISR_Run;	// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx2 = 1;	// PIE level enable, Grp3 / Int2
// EPWM2 level enable
	EPwm2Regs.ETSEL.bit.INTSEL = 1;		// Select INT on Zero event
	EPwm2Regs.ETSEL.bit.INTEN = 1; 		// Enable INT
	//EPwm2Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm2Regs.ETPS.bit.INTPRD = ET_2ND;	// Generate INT every 2nd event
	//EPwm2Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM2_triggers_ISR)
//---------------------------------------------------------------------

#if (EPWM3_triggers_ISR) // Here ISR is triggered by EPWM3
//---------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM3_INT = &ISR_Run;	// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx3 = 1;	// PIE level enable, Grp3 / Int3
// EPWM3 level enable
	EPwm3Regs.ETSEL.bit.INTSEL = 1;		// Select INT on Zero event
	EPwm3Regs.ETSEL.bit.INTEN = 1; 		// Enable INT
	//EPwm3Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm3Regs.ETPS.bit.INTPRD = ET_2ND;	// Generate INT every 2nd event
	//EPwm3Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM3_triggers_ISR)
//---------------------------------------------------------------------

#if (EPWM4_triggers_ISR) // Here ISR is triggered by EPWM4
//---------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM4_INT = &ISR_Run;	// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx4 = 1;	// PIE level enable, Grp3 / Int4
// EPWM4 level enable
	EPwm4Regs.ETSEL.bit.INTSEL = 1;		// Select INT on Zero event
	EPwm4Regs.ETSEL.bit.INTEN = 1; 		// Enable INT
	//EPwm4Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm4Regs.ETPS.bit.INTPRD = ET_2ND;	// Generate INT every 2nd event
	//EPwm4Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM4_triggers_ISR)
//---------------------------------------------------------------------

#if (EPWM5_triggers_ISR) // Here ISR is triggered by EPWM5
//---------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM5_INT = &ISR_Run;	// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx5 = 1;	// PIE level enable, Grp3 / Int5
// EPWM5 level enable
	EPwm5Regs.ETSEL.bit.INTSEL = 1;		// Select INT on Zero event
	EPwm5Regs.ETSEL.bit.INTEN = 1; 		// Enable INT
	//EPwm5Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm5Regs.ETPS.bit.INTPRD = ET_2ND;	// Generate INT every 2nd event
	//EPwm5Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM5_triggers_ISR)
//---------------------------------------------------------------------

#if (EPWM6_triggers_ISR) // Here ISR is triggered by EPWM6
//---------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM6_INT = &ISR_Run;	// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx6 = 1;	// PIE level enable, Grp3 / Int6
// EPWM6 level enable
	EPwm6Regs.ETSEL.bit.INTSEL = 1;		// Select INT on Zero event
	EPwm6Regs.ETSEL.bit.INTEN = 1; 		// Enable INT
	//EPwm6Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm6Regs.ETPS.bit.INTPRD = ET_2ND;	// Generate INT every 2nd event
	//EPwm6Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM6_triggers_ISR)
//---------------------------------------------------------------------
#endif // (EPWMn_ISR)
//===========================================================================

#if (ADC_ISR) // Here ISR is triggered by the ADC EOS
//===========================================================================
	IER |= M_INT1; // Enable CPU INT1 which is connected to ADC INT

	EALLOW;
	PieVectTable.ADCINT = &ISR_Run;		// Map Interrupt
	EDIS;
   	PieCtrlRegs.PIEIER1.bit.INTx6 = 1;	// PIE level enable, Grp1 / Int6

// ADC Specific Enables
//----------------------
	// ADC level enable
   AdcRegs.ADCTRL2.bit.EPWM_SOCA_SEQ1 = 1;// Enable SOCA from ePWM to start SEQ1
   AdcRegs.ADCTRL2.bit.INT_ENA_SEQ1 = 1;  // Enable SEQ1 interrupt (every EOS)
	// Allow the ADC SOC from an EPWM trigger.  This is not related to Interrupt
	// init, but makes sense to do it here.
   EPwm1Regs.ETSEL.bit.SOCAEN = 1;        		// Enable SOC on A group
   EPwm1Regs.ETSEL.bit.SOCASEL = ET_CTR_ZERO;	// SOC on CTR=Zero event
   EPwm1Regs.ETPS.bit.SOCAPRD = ET_1ST;        	// Trigger on every event
#endif // (ADC_ISR)
//===========================================================================


// Enable global Interrupts and higher priority real-time debug events:
//===========================================================================
	EINT;   // Enable Global interrupt INTM
	ERTM;   // Enable Global realtime interrupt DBGM
//===========================================================================

// Backgound Loop
	for(;;)
	{
	BackTicker++;

#if (IB11) // HiRes Buck driver checkout
//---------------------------------------------------------------------
		SFO_MepDis(4);
		SFBUCK1 = MEP_ScaleFactor[4] * 256;		// used for HR-Buck

#endif // (IB11)
//---------------------------------------------------------------------


#if (IB14) // HiRes PSFB driver checkout
//---------------------------------------------------------------------
		SFO_MepDis(4);
		SFPSFB = MEP_ScaleFactor[4] * 256;		// used for HR-PSFB		
#endif // (IB13)
//---------------------------------------------------------------------


#if (IB15A||IB15B) // HiRes PWM DAC driver checkout
//---------------------------------------------------------------------
//		SFO_MepEn(1);
		SFO_MepEn(3);
		SFO_MepDis(2);
		SFO_MepDis(4);
		SFBUCK1 = MEP_ScaleFactor[1] * 256;		// used for HR-PWMDAC		
#endif // (IB15A||IB15B)
//---------------------------------------------------------------------


	}
} 

