;----------------------------------------------------------------------------------
;	FILE:			HR_PWM_Demo_Isr.ASM
;
;	Description:	ASM ISR to evaluate PWM driver modules
;
;	Version: 		2.00
;
;   Target:  		TMS320F280x (F2808, F2806, F2801). 
;
;	Type: 			Device dependent
;
;----------------------------------------------------------------------------------
;  Copyright Texas Instruments  2004-2006                                			
;----------------------------------------------------------------------------------
;  Revision History:
;----------------------------------------------------------------------------------
;  Date	     | Description
;----------------------------------------------------------------------------------
;  06/30/05  | Release 1.0  	   New release.
;----------------------------------------------------------------------------------
;  11/15/05  | Release 1.1  	   Documentation and source cleanup.
;---------------------------------------------------------------------------------- 
;---------------------------------------------------------------------------------- 
;  06/27/06  | Release 2.0  	   Updated all the projects to the rev 2.0  format
;            |                     with the addition of memory blocking and new
;            |                     directory structure and simplified libraries.
;---------------------------------------------------------------------------------- 
	.include "dplib280x.inc"

;**********************************************************************************
; Assembly Configuration Switches:
;**********************************************************************************
; Make sure this selection matches the choice in PWM-Eval-Main.c
EPWM_ISR		.set	1	; for EPWM triggered ISR
ADC_ISR			.set	0	; for ADC triggered ISR
NET_DEBUG		.set	0


; HiRes examples
IB11		.set	0	; HR-Buck - Single module (w.o. Dead-band)
IB14		.set	0	; HR-Phase Shifted Full Bridge w/ DB control
IB15A		.set	1	; HiRes PWM-DAC module with Sine modulation
IB15B		.set	0	; HiRes PWM-DAC module with Ramp modulation

;**********************************************************************************
; Declare Public functions for External Reference
;**********************************************************************************
				.def 	_ISR_Init
				.def 	_ISR_Run


;**********************************************************************************
; Variable declaration
;**********************************************************************************	
; All Terminal modules initially point to the ZeroNet to ensure a known
; start state. Pad extra locations to accomodate unwanted ADC results.
ZeroNet			.usect "Net_terminals",8,1,1
DummyNet	 	.usect "Net_terminals",1

			.text
;______________________________________________________________________________
;
; Type:		Asm Function
; Name: 	_ISR_Init
;
; Description:
; ------------
; Framework initialization function.
; 	o  Reserve Macro Module data memory
;	o  Initialize all signal nets to known value
;
;; Revision History:
;------------------------------------------------------------------------------
; Date		| Author	| Description
;------------------------------------------------------------------------------
; 11/18/04	| DAF		| Added conditional ASM for PWM driver eval  
; 5 Apr 05	| DAF		| Added several more module checkout examples
;______________________________________________________________________________
_ISR_Init


; HiRes examples
;=========================
	;---------------------------------------------------------
	.if(IB11)
			HRBUCK_DRV_INIT 1
	.endif ; IB11
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB14)
			HR_PSFB_DRV_INIT
	.endif ; IB14
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB15A)
			SINGEN_1CH_INIT     1	; Instantiation #1
			HRBUCK_DRV_INIT    1	; Instantiation #1
			BUCK_DRV_INIT 		2	; Bind to EPWM2
	.endif ; IB15A
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB15B)
			RAMPGEN_1CH_INIT    1	; Instantiation #1
			HRBUCK_DRV_INIT   1	; Instantiation #1
			BUCK_DRV_INIT 		2	; Bind to EPWM2
	.endif ; IB15B
	;---------------------------------------------------------


			LRETR

;______________________________________________________________________________
;
; Type:		Asm Function
; Name: 	_ISR_Run
;
; Description:
; ------------
; Framework ISR
; 	o  Manages Time Slice execution
;	o  Executes Cintrol flow Macro Modules
;	o  Handles Interrupt acknowledges and flag clearing
;
;; Revision History:
;------------------------------------------------------------------------------
; Date		| Author	| Description
;------------------------------------------------------------------------------
; 11/18/04	| DAF		| Modified for Signal Net and Macro interface 
; 5 Apr 05	| DAF		| Added several more module checkout examples
;______________________________________________________________________________
_ISR_Run:	CONTEXT_SAVE		;call macro	

; HiRes examples
;=========================  
	.ref 	_WriteFlag       
	.ref 	_WriteValue

	;---------------------------------------------------------
	.if(IB11)
			HRBUCK_DRV 1        
	.endif ; IB11
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB14)
			HR_PSFB_DRV
	.endif ; IB14
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB15A)
			SINGEN_1CH    1		; Instantiation #1
			HRBUCK_DRV    1		; Instantiation #1
			BUCK_DRV      2		; Bind to EPWM2
	.endif ; IB15A
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB15B)
			RAMPGEN_1CH   1		; Instantiation #1
			HRBUCK_DRV    1		; Instantiation #1
			BUCK_DRV      2		; Bind to EPWM2
	.endif ; IB15B
	;---------------------------------------------------------

;===================================
EXIT_ISR
;===================================
; Interrupt management before exit

	.if(EPWM_ISR)
	; Case where ISR is triggered by EPWM1/4 
;			MOVW 	DP,#ETCLR1>>6
;			MOV 	@ETCLR1,#0x01			; Clear EPWM1 Int flag

;			MOVW 	DP,#ETCLR4>>6
;			MOV 	@ETCLR4,#0x01			; Clear EPWM4 Int flag

			MOVW 	DP,#ETCLR6>>6
			MOV 	@ETCLR6,#0x01			; Clear EPWM6 Int flag

			MOVW 	DP,#PIEACK>>6			; Acknowledge PIE interrupt Group 3
			MOV 	@PIEACK,#PIEACK_GROUP3
	.endif ; EPWM_ISR


	.if(ADC_ISR)
	; Case where ISR is triggered by ADC 
			MOVW 	DP,#ADCST>>6
			MOV 	@ADCST,#0x010			; Clear INT SEQ1 Int flag

			MOVW 	DP,#PIEACK>>6			; Acknowledge PIE interrupt Group 1
			MOV 	@PIEACK,#PIEACK_GROUP1
	.endif ; ADC_ISR

; Restore context & return
			CONTEXT_REST
			IRET						

