//----------------------------------------------------------------------------------
//	FILE:			PWM_Demo.C
//
//	Description:	PWM s/w driver demonstration examples
//
//	Version: 		2.00
//
//  Target:  		TMS320F280x (F2808, F2806, F2801).
//
//	Type: 			Device dependent
//
//----------------------------------------------------------------------------------
//  Copyright Texas Instruments  2004-2006                                				
//----------------------------------------------------------------------------------
//  Revision History:
//----------------------------------------------------------------------------------
//  Date	  | Description
//----------------------------------------------------------------------------------
//  06/30/05  | Release 1.0  		New release.
//----------------------------------------------------------------------------------
//  11/15/05  | Release 1.1  		Documentation and source cleanup.
//---------------------------------------------------------------------------------- 
//  06/27/06  | Release 2.0  		Updated all the projects to the rev 2.0  format
//            |                     with the addition of memory blocking and new
//            |                     directory structure and simplified libraries.
//---------------------------------------------------------------------------------- 
#include "DSP280x_Compact.h"     	// DSP280x Headerfile
#include "Dplib280x.h"				// Digital Power Library Definitions
//----------------------------------------------------------------------------------
// Build options for module check-out
//----------------------------------------------------------------------------------
// Notes: 
// o  make sure same conditional assembly option is chosen in file
//    PWM_Demo_ISR.asm
// o  choose only one option at a time, and re-build before running
//----------------------------------------------------------------------------------
// Non-HiRes examples
#define	IB1A	1	// Buck - 1 module instance  (2 Indep duty outputs)
#define	IB1B	0	// Buck - 2 module instances (4 Indep duty outputs)
#define	IB2A	0	// Multiphase Interleaved (2 phase example)
#define	IB2B	0	// Multiphase Interleaved (3 phase example)
#define	IB2C	0	// Multiphase Interleaved (4 phase example)
#define	IB5		0	// Phase Shifted Full Bridge w/DB control
//----------------------------------------------------------------------------------

//----------------------------------------------------------------------------------
// Interrupt Framework options
//----------------------------------------------------------------------------------
// Note: make sure same conditional assembly option is chosen in
// file PWM_Demo_ISR.asm
//----------------------------------------------------------------------------------
#define	EPWMn_ISR	1	// ISR triggered by EPWM
#define	ADC_ISR		0	// ISR triggered by ADC EOS

// If EPWM_ISR = 1, then choose which module
#define	EPWM1_triggers_ISR	0	// ISR triggered by EPWM1
#define	EPWM2_triggers_ISR	0	// ISR triggered by EPWM2
#define	EPWM3_triggers_ISR	0	// ISR triggered by EPWM3
#define	EPWM4_triggers_ISR	0	// ISR triggered by EPWM4
#define	EPWM5_triggers_ISR	0	// ISR triggered by EPWM5
#define	EPWM6_triggers_ISR	1	// ISR triggered by EPWM6
//----------------------------------------------------------------------------------
// General System Prototype statements
//----------------------------------------------------------------------------------
// This is standard system init stuff, no need to change
void InitSysCtrl(void);
void InitPieCtrl(void);
void InitPieVectTable(void);


// Declare function prototypes here
//----------------------------------------------------------------------------------
void ISR_Init(void);
void ISR_Run(void);


//----------------------------------------------------------------------------------
// Variable Declarations
//----------------------------------------------------------------------------------
// General "System nets" - Useful for module evaluation
	int16 phase, dbLeft, dbRight;
	int16 duty1, duty2, duty3, duty4;
	Uint32 BackTicker = 0;

//----------------------------------------------------------------------------------
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
void main(void)
{
//==================================================================================
// Generic Chip level Init.
//==================================================================================
	InitSysCtrl();
	DINT;
	InitPieCtrl();
   
// 	Disable CPU interrupts and clear all CPU interrupt flags:
	IER = 0x0000;
	IFR = 0x0000;
	InitPieVectTable();

// Configure the GPIO to EPWM functions

	EALLOW;
	GpioCtrlRegs.GPAMUX1.all=0x55555555; // GPIO0-15 for PWM 

	// master clock sync/enable for all ePWMs
	SysCtrlRegs.PCLKCR0.bit.TBCLKSYNC = 1;
	EDIS;

//==================================================================================

//==================================================================================
// Other One-Time Initialize Fuctions
//==================================================================================
// None so far.


//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Incremental build options via Module connections to system Nets.
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

// Some useful Period vs Frequency values for Sysclk = 100 MHz
//	Period	Frequency
//	1000	100 KHz
//	800		125 KHz
//	600		167 KHz
//	500		200 KHz
//	400		250 KHz
//	300		333 KHz
//	250		400 KHz
//	200		500 KHz
//	100		1 MHz
//	50		2 MHz
//	25		4 MHz
//	12		8.33 MHz
//	10		10.0 MHz

//==================================================================================
#if (IB1A) // 1 x 2 Channel Buck PWM driver checkout
//==================================================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		BuckDrvCnf(1, 500);			// ePWM1 target, 200KHz PWM
		ISR_Init();					// ASM ISR init

		duty1 = 0x6000;
		duty2 = 0x3000;
		BUCK_InA1 = &duty1;
		BUCK_InB1 = &duty2;

#endif // (IB1A)

//==================================================================================
#if (IB1B) // 2 x 2 Channel Buck PWM driver checkout
//==================================================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		BuckDrvCnf(1, 500);			// ePWM1 target, 200KHz PWM
		BuckDrvCnf(2, 500);			// ePWM2 target, 200KHz PWM
		ISR_Init();					// ASM ISR init

		duty1 = 0x6000;
		duty2 = 0x4000;
		duty3 = 0x2000;
		duty4 = 0x1000;

		BUCK_InA1 = &duty1;
		BUCK_InB1 = &duty2;
		BUCK_InA2 = &duty3;
		BUCK_InB2 = &duty4;

#endif // (IB1B)

//==================================================================================
#if (IB2A) // Multi-Phase Interleaved Buck driver, 2 phase checkout
//==================================================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		MPILDrvCnf(1, 2, 200);		// ePWM1=phase1, 2 phase, 500 KHz PWM
		ISR_Init();					// ASM ISR init

		duty1 		= 0x2000;				// 25% duty initially
		MPIL_Duty1 	= &duty1;

#endif // (IB2A)


//==================================================================================
#if (IB2B) // Multi-Phase Interleaved Buck driver, 3 phase checkout
//==================================================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		MPILDrvCnf(1, 3, 300);		// ePWM1=phase1, 3 phase, 333 KHz PWM
		ISR_Init();					// ASM ISR init

		duty1 = 0x2000;				// 25% duty initially
		MPIL_Duty1 = &duty1;

#endif // (IB2B)

//==================================================================================
#if (IB2C) // Multi-Phase Interleaved Buck driver, 3 phase checkout
//==================================================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		MPILDrvCnf(1, 4, 400);		// ePWM1=phase1, 3 phase, 250 KHz PWM
		ISR_Init();					// ASM ISR init
	
		duty1 = 0x2000;				// 25% duty initially
		MPIL_Duty1 = &duty1;
#endif // (IB2C)


//==================================================================================
#if (IB5) // PSFB PWM driver checkout
//==================================================================================
		TimeBasePeriodCnf(6, 1000);	// ISR Timebase only, 100KHz
		PSFBDrvCnf(1, 500);			// ePWM module 1 & 2, 200KHz
		ISR_Init();					// ASM ISR init

		phase    = 0;
		dbLeft   = 20;
		dbRight  = 30;

		PSFB_phase1   = &phase;
		PSFB_dbLeft1  = &dbLeft;
		PSFB_dbRight1 = &dbRight;
#endif // (IB5)

//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// Interrupt Init section - System Level and Peripheral Level
// (best to run this section last, once all other initialization is done)
//
// Note: Make sure same selection is made in PWM-Eval-ISR.ASM
//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#if (EPWMn_ISR) // Here ISR is triggered by EPWMn
//----------------------------------------------------------------------------------
	IER |= M_INT3; // Enable CPU INT3 connected to EPWM1-6 INTs:


#if (EPWM1_triggers_ISR) // Here ISR is triggered by EPWM1
//----------------------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM1_INT = &ISR_Run;		// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx1 = 1;		// PIE level enable, Grp3 / Int1
// EPWM1 level enable
	EPwm1Regs.ETSEL.bit.INTSEL = 1;			// Select INT on Zero event
	EPwm1Regs.ETSEL.bit.INTEN = 1; 			// Enable INT
	//EPwm1Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm1Regs.ETPS.bit.INTPRD = ET_2ND;		// Generate INT every 2nd event
	//EPwm1Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM1_triggers_ISR)
//----------------------------------------------------------------------------------

#if (EPWM2_triggers_ISR) // Here ISR is triggered by EPWM2
//----------------------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM2_INT = &ISR_Run;		// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx2 = 1;		// PIE level enable, Grp3 / Int2
// EPWM2 level enable
	EPwm2Regs.ETSEL.bit.INTSEL = 1;			// Select INT on Zero event
	EPwm2Regs.ETSEL.bit.INTEN = 1; 			// Enable INT
	//EPwm2Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm2Regs.ETPS.bit.INTPRD = ET_2ND;		// Generate INT every 2nd event
	//EPwm2Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM2_triggers_ISR)
//----------------------------------------------------------------------------------

#if (EPWM3_triggers_ISR) // Here ISR is triggered by EPWM3
//----------------------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM3_INT = &ISR_Run;		// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx3 = 1;		// PIE level enable, Grp3 / Int3
// EPWM3 level enable
	EPwm3Regs.ETSEL.bit.INTSEL = 1;			// Select INT on Zero event
	EPwm3Regs.ETSEL.bit.INTEN = 1; 			// Enable INT
	//EPwm3Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm3Regs.ETPS.bit.INTPRD = ET_2ND;		// Generate INT every 2nd event
	//EPwm3Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM3_triggers_ISR)
//----------------------------------------------------------------------------------

#if (EPWM4_triggers_ISR) // Here ISR is triggered by EPWM4
//----------------------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM4_INT = &ISR_Run;		// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx4 = 1;		// PIE level enable, Grp3 / Int4
// EPWM4 level enable
	EPwm4Regs.ETSEL.bit.INTSEL = 1;			// Select INT on Zero event
	EPwm4Regs.ETSEL.bit.INTEN = 1; 			// Enable INT
	//EPwm4Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm4Regs.ETPS.bit.INTPRD = ET_2ND;		// Generate INT every 2nd event
	//EPwm4Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM4_triggers_ISR)
//----------------------------------------------------------------------------------

#if (EPWM5_triggers_ISR) // Here ISR is triggered by EPWM5
//----------------------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM5_INT = &ISR_Run;		// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx5 = 1;		// PIE level enable, Grp3 / Int5
// EPWM5 level enable
	EPwm5Regs.ETSEL.bit.INTSEL = 1;			// Select INT on Zero event
	EPwm5Regs.ETSEL.bit.INTEN = 1; 			// Enable INT
	//EPwm5Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm5Regs.ETPS.bit.INTPRD = ET_2ND;		// Generate INT every 2nd event
	//EPwm5Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM5_triggers_ISR)
//----------------------------------------------------------------------------------

#if (EPWM6_triggers_ISR) // Here ISR is triggered by EPWM6
//----------------------------------------------------------------------------------
	EALLOW;
	PieVectTable.EPWM6_INT = &ISR_Run;		// Map Interrupt
	EDIS;
	PieCtrlRegs.PIEIER3.bit.INTx6 = 1;		// PIE level enable, Grp3 / Int6
// EPWM6 level enable
	EPwm6Regs.ETSEL.bit.INTSEL = 1;			// Select INT on Zero event
	EPwm6Regs.ETSEL.bit.INTEN = 1; 			// Enable INT
	//EPwm6Regs.ETPS.bit.INTPRD = ET_1ST;	// Generate INT on every event
	EPwm6Regs.ETPS.bit.INTPRD = ET_2ND;		// Generate INT every 2nd event
	//EPwm6Regs.ETPS.bit.INTPRD = ET_3RD;	// Generate INT every 3rd event
#endif // (EPWM6_triggers_ISR)
//----------------------------------------------------------------------------------
#endif // (EPWMn_ISR)
//==================================================================================



#if (ADC_ISR) // Here ISR is triggered by the ADC EOS
//==================================================================================
	IER |= M_INT1; // Enable CPU INT1 which is connected to ADC INT

	EALLOW;
	PieVectTable.ADCINT = &ISR_Run;			// Map Interrupt
	EDIS;
   	PieCtrlRegs.PIEIER1.bit.INTx6 = 1;		// PIE level enable, Grp1 / Int6

// ADC Specific Enables
//----------------------
	// ADC level enable
   AdcRegs.ADCTRL2.bit.EPWM_SOCA_SEQ1 = 1;	// Enable SOCA from ePWM to start SEQ1
   AdcRegs.ADCTRL2.bit.INT_ENA_SEQ1 = 1;  	// Enable SEQ1 interrupt (every EOS)
	// Allow the ADC SOC from an EPWM trigger.  This is not related to Interrupt
	// init, but makes sense to do it here.
   EPwm1Regs.ETSEL.bit.SOCAEN = 1;        		// Enable SOC on A group
   EPwm1Regs.ETSEL.bit.SOCASEL = ET_CTR_ZERO;	// SOC on CTR=Zero event
   EPwm1Regs.ETPS.bit.SOCAPRD = ET_1ST;        	// Trigger on every event
#endif // (ADC_ISR)
//==================================================================================

// Enable global Interrupts and higher priority real-time debug events:
//==================================================================================

	EINT;   // Enable Global interrupt INTM
	ERTM;   // Enable Global realtime interrupt DBGM
//==================================================================================

// Backgound Loop
	for(;;)
	{
	BackTicker++;
	}
} 
