;----------------------------------------------------------------------------------
;	FILE:			PWM_Demo_ISR.ASM
;
;	Description:	ASM ISR to evaluate PWM driver modules
;
;	Version: 		2.00
;
;   Target:  		TMS320F280x (F2808, F2806, F2801) 
;
;	Type: 			Device dependent
;
;----------------------------------------------------------------------------------
;  Copyright Texas Instruments  2004-2006                                			
;----------------------------------------------------------------------------------
;  Revision History:
;----------------------------------------------------------------------------------
;  Date	     | Description
;----------------------------------------------------------------------------------
;  06/30/05  | Release 1.0  		New release.
;----------------------------------------------------------------------------------
;  11/15/05  | Release 1.1  		Documentation and source cleanup.
;---------------------------------------------------------------------------------- 
;  06/27/06  | Release 2.0  		Updated all the projects to the rev 2.0  format
;            |                      with the addition of memory blocking and new
;            |                      directory structure and simplified libraries.
;---------------------------------------------------------------------------------- 
	.include "dplib280x.inc"

;**********************************************************************************
; Assembly Configuration Switches:
; Make sure this selection matches the choice in PWM_Demo.c
; Choose only one option at a time, and re-build before running
;**********************************************************************************
; ISR and ADC trigger options
EPWM_ISR		.set	1	; for EPWM triggered ISR
ADC_ISR			.set	0	; for ADC triggered ISR


; Non-HiRes examples
IB1A		.set	1	; Buck - 1 module instance (2 Indep duty outputs)
IB1B		.set	0	; Buck - 2 module instances (4 Indep duty outputs)
IB2A		.set	0	; Multiphase Interleaved (2 phase example)
IB2B		.set	0	; Multiphase Interleaved (3 phase example)
IB2C		.set	0	; Multiphase Interleaved (4 phase example)
IB5			.set	0	; Phase Shifted Full Bridge w/ DB control



; If EPWM_ISR = 1, then choose which module
EPWM1_triggers_ISR	.set	0	; ISR triggered by EPWM1
EPWM2_triggers_ISR	.set	0	; ISR triggered by EPWM2
EPWM3_triggers_ISR	.set	0	; ISR triggered by EPWM3
EPWM4_triggers_ISR	.set	0	; ISR triggered by EPWM4
EPWM5_triggers_ISR	.set	0	; ISR triggered by EPWM5
EPWM6_triggers_ISR	.set	1	; ISR triggered by EPWM6


;**********************************************************************************
; Declare Public functions for External Reference
;**********************************************************************************
				.def 	_ISR_Init
				.def 	_ISR_Run


;**********************************************************************************
; Variable declaration
;**********************************************************************************	
; All Terminal modules initially point to the ZeroNet to ensure a known
; start state. Pad extra locations to accomodate unwanted ADC results.
ZeroNet			.usect "Net_terminals",8,1,1
DummyNet	 	.usect "Net_terminals",1

			.text
;----------------------------------------------------------------------------------
; ISR initialisation section 
;----------------------------------------------------------------------------------
_ISR_Init

	;---------------------------------------------------------
	.if(IB1A)
			BUCK_DRV_INIT 1
	.endif ; IB1A
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB1B)
			BUCK_DRV_INIT 1
			BUCK_DRV_INIT 2
	.endif ; IB1B
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB2A)
			MPIL_DRV_INIT 1, 2		; start at ePWM1, 2-phase
	.endif ; IB2A
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB2B)
			MPIL_DRV_INIT 1, 3		; start at ePWM1, 3-phase
	.endif ; IB2B
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB2C)
			MPIL_DRV_INIT 1, 4		; start at ePWM1, 4-phase
	.endif ; IB2C
	;---------------------------------------------------------


	;---------------------------------------------------------
	.if(IB5)
			PSFB_DRV_INIT	1
	.endif ; IB5
	;---------------------------------------------------------

			LRETR

;----------------------------------------------------------------------------------
; ISR Run-time section 
;----------------------------------------------------------------------------------
_ISR_Run:	CONTEXT_SAVE		;call macro	

	;---------------------------------------------------------
	.if(IB1A)
			BUCK_DRV	1
	.endif ; IB1A
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB1B)
			BUCK_DRV	1
			BUCK_DRV	2
	.endif ; IB1B
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB2A)
			MPIL_DRV 1, 2		; start at ePWM1, 2-phase
	.endif ; IB2A
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB2B)
			MPIL_DRV 1, 3		; start at ePWM1, 3-phase
	.endif ; IB2B
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB2C)
			MPIL_DRV 1, 4		; start at ePWM1, 4-phase
	.endif ; IB2C
	;---------------------------------------------------------

	;---------------------------------------------------------
	.if(IB5)
			PSFB_DRV	1
	.endif ; IB5
	;---------------------------------------------------------

;===================================
EXIT_ISR
;===================================
; Interrupt management before exit

	.if(EPWM_ISR)

	;---------------------------------------------------------
	.if(EPWM1_triggers_ISR)
			MOVW 	DP,#ETCLR1>>6
			MOV 	@ETCLR1,#0x01			; Clear EPWM1 Int flag
	.endif ; EPWM1_triggers_ISR
	;---------------------------------------------------------
	.if(EPWM2_triggers_ISR)
			MOVW 	DP,#ETCLR2>>6
			MOV 	@ETCLR2,#0x01			; Clear EPWM2 Int flag
	.endif ; EPWM2_triggers_ISR
	;---------------------------------------------------------
	.if(EPWM3_triggers_ISR)
			MOVW 	DP,#ETCLR3>>6
			MOV 	@ETCLR3,#0x01			; Clear EPWM3 Int flag
	.endif ; EPWM3_triggers_ISR
	;---------------------------------------------------------
	.if(EPWM4_triggers_ISR)
			MOVW 	DP,#ETCLR4>>6
			MOV 	@ETCLR4,#0x01			; Clear EPWM4 Int flag
	.endif ; EPWM4_triggers_ISR
	;---------------------------------------------------------
	.if(EPWM5_triggers_ISR)
			MOVW 	DP,#ETCLR5>>6
			MOV 	@ETCLR5,#0x01			; Clear EPWM5 Int flag
	.endif ; EPWM5_triggers_ISR
	;---------------------------------------------------------
	.if(EPWM6_triggers_ISR)
			MOVW 	DP,#ETCLR6>>6
			MOV 	@ETCLR6,#0x01			; Clear EPWM6 Int flag
	.endif ; EPWM6_triggers_ISR
	;---------------------------------------------------------

			MOVW 	DP,#PIEACK>>6			; Acknowledge PIE interrupt Group 3
			MOV 	@PIEACK,#PIEACK_GROUP3
	.endif ; EPWM_ISR


	.if(ADC_ISR)
	; Case where ISR is triggered by ADC 
			MOVW 	DP,#ADCST>>6
			MOV 	@ADCST,#0x010			; Clear INT SEQ1 Int flag

			MOVW 	DP,#PIEACK>>6			; Acknowledge PIE interrupt Group 1
			MOV 	@PIEACK,#PIEACK_GROUP1
	.endif ; ADC_ISR

; Restore context & return
			CONTEXT_REST
			IRET						
